@@ -27,13 +27,21 @@ p <- matrix(c(1L,2L,3L, 2L,2L,2L), nrow = 2L, byrow = TRUE)
 
 .Call("_ini_array", 3L, c(1L,2L), c(1L,1L), 2L)
 
-.Call("_split_row", array(c(1L,2L), c(2L, 2L)))
 .Call("_split_col", array(c(1L,2L), c(2L, 2L)))
 
 ##
 x <- matrix(c(1L,1L,1L,1L,1L,2L,1L,3L,1L,2L), 
 	    ncol = 2, byrow = TRUE)
 x
-.Call("_match_matrix", x)
+.Call("_match_matrix", x, NULL, NULL)
+.Call("_match_matrix", x, x[1:3,], 0L)
+
+
+##
+x <- matrix(c(1L,2L,2L,2L,NA,1L,NA,2L,NA,NA), 
+	    ncol = 2, byrow = TRUE)
+x
+.Call("_all_row", x > 1L, FALSE)
+.Call("_all_row", x > 1L, TRUE)
 
 ###
